import { describe, it, expect } from 'vitest'
import { calcTimeOfDay, renderClock, calcSunAngle } from './useTime'

describe('useTime composable', () => {
  describe('clock', () => {
    it('renders 2:00 at tick 0', () => {
      expect(renderClock(0)).toEqual('2:00')
    })
    it('renders 14:00 at tick 500', () => {
      expect(renderClock(500)).toEqual('14:00')
    })
    it('does not break on meanless values', () => {
      expect(renderClock(9500)).toBeDefined()
      expect(renderClock(-500)).toBeDefined()
    })
  })
  describe('time of day', () => {
    it('sets the correct time of day', () => {
      expect(calcTimeOfDay(0)).toEqual('night')
      expect(calcTimeOfDay(900)).toEqual('night')
      expect(calcTimeOfDay(100)).toEqual('morning0')
      expect(calcTimeOfDay(145)).toEqual('morning1')
      expect(calcTimeOfDay(200)).toEqual('morning2')
      expect(calcTimeOfDay(700)).toEqual('evening0')
      expect(calcTimeOfDay(800)).toEqual('evening1')
      expect(calcTimeOfDay(850)).toEqual('evening2')
      expect(calcTimeOfDay(300)).toEqual('day')
      expect(calcTimeOfDay(400)).toEqual('day')
      expect(calcTimeOfDay(555)).toEqual('day')
    })
  })
  describe('sun angle', () => {
    it('returns -10 degrees over night', () => {
      expect(calcSunAngle(900)).toEqual(-10)
      expect(calcSunAngle(945)).toEqual(-10)
      expect(calcSunAngle(0)).toEqual(-10)
      expect(calcSunAngle(57)).toEqual(-10)
    })
    it('returns -90 degrees over day', () => {
      expect(calcSunAngle(250)).toEqual(-90)
      expect(calcSunAngle(300)).toEqual(-90)
      expect(calcSunAngle(557)).toEqual(-90)
      expect(Math.round(calcSunAngle(699))).toEqual(-90)
    })
    it('raises in the morning', () => {
      expect(calcSunAngle(100)).toEqual(-20)
      expect(calcSunAngle(150)).toEqual(-45)
      expect(calcSunAngle(200)).toEqual(-70)
      expect(calcSunAngle(240)).toEqual(-90)
    })
    it('sinks in the evening', () => {
      expect(calcSunAngle(700)).toEqual(-90)
      expect(calcSunAngle(750)).toEqual(-70)
      expect(calcSunAngle(800)).toEqual(-50)
      expect(Math.round(calcSunAngle(899))).toEqual(-10)
    })
  })
})
